@@ -5,7 +5,7 @@ use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 use Role::Basic;
 
-our $VERSION = '0.1.0_9';
+our $VERSION = '0.1.0_11';
 
 my %import_functions = (
     NEW => {
@@ -45,10 +45,13 @@ sub real_import_repo {
     }
 
     my $ucount;
+    my $on_update = $self->on_update;
 
     while ( $total-- > 0 ) {
         my ( $action, $type, $ref ) = $self->read;
 
+        $on_update->( 'inbound updates: ' . $total ) if $on_update;
+
         if ( !exists $import_functions{$action} ) {
             $self->write( 'BadMethod', $action );
             return 'BadMethod';
@@ -87,7 +90,6 @@ sub real_import_repo {
 
     $self->write('RepoImported');
     my ($action) = $self->read;
-    $db->do('ANALYZE');
     return 'RepoImported' if $action eq 'RepoExported';
     return $action;
 }
@@ -99,8 +101,9 @@ sub real_sync_repo {
     my $tmp    = shift || 'sync_' . sprintf( "%08x", rand(0xFFFFFFFF) );
 
     $prefix = '' unless defined $prefix;
-    my $prefix2 = $prefix . '_';
-    my $db      = $self->db;
+    my $prefix2   = $prefix . '_';
+    my $db        = $self->db;
+    my $on_update = $self->on_update;
 
     $db->do("CREATE TEMPORARY TABLE $tmp(id INTEGER, ucount INTEGER)")
       if ( $prefix eq '' );
@@ -121,6 +124,8 @@ sub real_sync_repo {
       and $mprefix eq $prefix2
       and ref $there eq 'HASH';
 
+    $on_update->( 'matching: ' . $prefix2 ) if $on_update;
+
     my @next;
     my @missing;
 
